@@ -4,7 +4,14 @@
 # FILE    : __init__
 # PROJECT : funfunc
 # IDE     : PyCharm
-__VERSION__ = "0.0.4"
+
+# from .cv import *
+# from .dl import *
+# from .ml import *
+# from .nlp import *
+# from .tool import *
+# from .tornado_helper import *
+
+__VERSION__ = "0.0.5"
 __AUTHOR__ = "Wei Jia"
 __DESCRIPTION__ = "Make Py Development Much Easier & Fun"
-__all__ = ['cv', 'dl', 'ml', 'nlp', 'tool', 'tornado_helper']
