@@ -12,7 +12,7 @@ import cv2
 
 
 def pil_image_to_base64_string(pil_image,
-                               image_format: typing.Literal['jpg', 'png', 'jpeg', 'bmp', 'gif']) -> str:
+                               image_format: typing.Literal['.jpg', '.png', '.jpeg', '.bmp']) -> str:
     temp_buffer = io.BytesIO()
     try:
         pil_image.save(temp_buffer, format=image_format)
@@ -48,7 +48,7 @@ def cv_image_to_pil_image(cv_image):
     return pil_image
 
 
-def cv_image_to_base64_string(cv_image, image_format: typing.Literal['jpg', 'png', 'jpeg', 'bmp', 'gif']) -> str:
+def cv_image_to_base64_string(cv_image, image_format: typing.Literal['.jpg', '.png', '.jpeg', '.bmp']) -> str:
     temp_string = cv2.imencode(image_format, cv_image)[1].tostring()
     base64_string = base64.b64encode(temp_string).decode('utf-8')
     return base64_string
