@@ -4,7 +4,7 @@
 # FILE    : tornado
 # PROJECT : funfunc
 # IDE     : PyCharm
-import tornado
+import tornado.web
 
 
 # 解决tornado-vue 跨域问题
